# This file contains methods to deal with criu images.
#
# According to http://criu.org/Images, criu images can be described
# with such IOW:
#
# IMAGE_FILE ::= MAGIC { ENTRY }
# ENTRY      ::= SIZE PAYLOAD [ EXTRA ]
# PAYLOAD    ::= "message encoded in ProtocolBuffer format"
# EXTRA      ::= "arbitrary blob, depends on the PAYLOAD contents"
#
# MAGIC      ::= "32 bit integer"
# SIZE       ::= "32 bit integer, equals the PAYLOAD length"
#
# Images v1.1 NOTE: MAGIC now consist of 2 32 bit integers, first one is
#    MAGIC_COMMON or MAGIC_SERVICE and the second one is same as MAGIC
#    in images V1.0. We don't keep "first" magic in json images.
#
# In order to convert images to human-readable format, we use dict(json).
# Using json not only allows us to easily read\write images, but also
# to use a great variety of tools out there to manipulate them.
# It also allows us to clearly describe criu images structure.
#
# Using dict(json) format, criu images can be described like:
#
# {
#    'magic' : 'FOO',
#    'entries' : [
#        entry,
#        ...
#    ]
# }
#
# Entry, in its turn, could be described as:
#
# {
#    pb_msg,
#    'extra' : extra_msg
# }
#
import io
import base64
import struct
import os
import array

from . import magic
from . import pb
from . import pb2dict

if "encodebytes" not in dir(base64):
    base64.encodebytes = base64.encodestring
    base64.decodebytes = base64.decodestring

#
# Predefined hardcoded constants
sizeof_u16 = 2
sizeof_u32 = 4
sizeof_u64 = 8


# A helper for rounding
def round_up(x, y):
    return (((x - 1) | (y - 1)) + 1)


class MagicException(Exception):
    def __init__(self, magic):
        self.magic = magic


def decode_base64_data(data):
    """A helper function to decode base64 data."""
    return base64.decodebytes(str.encode(data))


def write_base64_data(f, data):
    """A helper function to write base64 encoded data to a file."""
    f.write(base64.decodebytes(str.encode(data)))


# Generic class to handle loading/dumping criu images entries from/to bin
# format to/from dict(json).
class entry_handler:
    """
    Generic class to handle loading/dumping criu images
    entries from/to bin format to/from dict(json).
    """

    def __init__(self, payload, extra_handler=None):
        """
        Sets payload class and extra handler class.
        """
        self.payload = payload
        self.extra_handler = extra_handler

    def load(self, f, pretty=False, no_payload=False):
        """
        Convert criu image entries from binary format to dict(json).
        Takes a file-like object and returns a list with entries in
        dict(json) format.
        """
        entries = []

        while True:
            entry = {}

            # Read payload
            pbuff = self.payload()
            buf = f.read(4)
            if len(buf) == 0:
                break
            size, = struct.unpack('i', buf)
            pbuff.ParseFromString(f.read(size))
            entry = pb2dict.pb2dict(pbuff, pretty)

            # Read extra
            if self.extra_handler:
                if no_payload:

                    def human_readable(num):
                        for unit in ['', 'K', 'M', 'G', 'T', 'P', 'E', 'Z']:
                            if num < 1024.0:
                                if int(num) == num:
                                    return "%d%sB" % (num, unit)
                                else:
                                    return "%.1f%sB" % (num, unit)
                            num /= 1024.0
                        return "%.1fYB" % num

                    pl_size = self.extra_handler.skip(f, pbuff)
                    entry['extra'] = '... <%s>' % human_readable(pl_size)
                else:
                    entry['extra'] = self.extra_handler.load(f, pbuff)

            entries.append(entry)

        return entries

    def loads(self, s, pretty=False):
        """
        Same as load(), but takes a string as an argument.
        """
        f = io.BytesIO(s)
        return self.load(f, pretty)

    def dump(self, entries, f):
        """
        Convert criu image entries from dict(json) format to binary.
        Takes a list of entries and a file-like object to write entries
        in binary format to.
        """
        for entry in entries:
            extra = entry.pop('extra', None)

            # Write payload
            pbuff = self.payload()
            pb2dict.dict2pb(entry, pbuff)
            pb_str = pbuff.SerializeToString()
            size = len(pb_str)
            f.write(struct.pack('i', size))
            f.write(pb_str)

            # Write extra
            if self.extra_handler and extra:
                self.extra_handler.dump(extra, f, pbuff)

    def dumps(self, entries):
        """
        Same as dump(), but doesn't take file-like object and just
        returns a string.
        """
        f = io.BytesIO('')
        self.dump(entries, f)
        return f.read()

    def count(self, f):
        """
        Counts the number of top-level object in the image file
        """
        entries = 0

        while True:
            buf = f.read(4)
            if len(buf) == 0:
                break
            size, = struct.unpack('i', buf)
            f.seek(size, 1)
            entries += 1

        return entries


# Special handler for pagemap.img
class pagemap_handler:
    """
    Special entry handler for pagemap.img, which is unique in a way
    that it has a header of pagemap_head type followed by entries
    of pagemap_entry type.
    """

    def load(self, f, pretty=False, no_payload=False):
        entries = []

        pbuff = pb.pagemap_head()
        while True:
            buf = f.read(4)
            if len(buf) == 0:
                break
            size, = struct.unpack('i', buf)
            pbuff.ParseFromString(f.read(size))
            entries.append(pb2dict.pb2dict(pbuff, pretty))

            pbuff = pb.pagemap_entry()

        return entries

    def loads(self, s, pretty=False):
        f = io.BytesIO(s)
        return self.load(f, pretty)

    def dump(self, entries, f):
        pbuff = pb.pagemap_head()
        for item in entries:
            pb2dict.dict2pb(item, pbuff)
            pb_str = pbuff.SerializeToString()
            size = len(pb_str)
            f.write(struct.pack('i', size))
            f.write(pb_str)

            pbuff = pb.pagemap_entry()

    def dumps(self, entries):
        f = io.BytesIO('')
        self.dump(entries, f)
        return f.read()

    def count(self, f):
        return entry_handler(None).count(f) - 1


# Special handler for ghost-file.img
class ghost_file_handler:
    def load(self, f, pretty=False, no_payload=False):
        entries = []

        gf = pb.ghost_file_entry()
        buf = f.read(4)
        size, = struct.unpack('i', buf)
        gf.ParseFromString(f.read(size))
        g_entry = pb2dict.pb2dict(gf, pretty)

        if gf.chunks:
            entries.append(g_entry)
            while True:
                gc = pb.ghost_chunk_entry()
                buf = f.read(4)
                if len(buf) == 0:
                    break
                size, = struct.unpack('i', buf)
                gc.ParseFromString(f.read(size))
                entry = pb2dict.pb2dict(gc, pretty)
                if no_payload:
                    f.seek(gc.len, os.SEEK_CUR)
                else:
                    entry['extra'] = base64.encodebytes(f.read(gc.len)).decode('utf-8')
                entries.append(entry)
        else:
            if no_payload:
                f.seek(0, os.SEEK_END)
            else:
                g_entry['extra'] = base64.encodebytes(f.read()).decode('utf-8')
            entries.append(g_entry)

        return entries

    def loads(self, s, pretty=False):
        f = io.BytesIO(s)
        return self.load(f, pretty)

    def dump(self, entries, f):
        pbuff = pb.ghost_file_entry()
        item = entries.pop(0)
        pb2dict.dict2pb(item, pbuff)
        pb_str = pbuff.SerializeToString()
        size = len(pb_str)
        f.write(struct.pack('i', size))
        f.write(pb_str)

        if pbuff.chunks:
            for item in entries:
                pbuff = pb.ghost_chunk_entry()
                pb2dict.dict2pb(item, pbuff)
                pb_str = pbuff.SerializeToString()
                size = len(pb_str)
                f.write(struct.pack('i', size))
                f.write(pb_str)
                write_base64_data(f, item['extra'])
        else:
            write_base64_data(f, item['extra'])

    def dumps(self, entries):
        f = io.BytesIO('')
        self.dump(entries, f)
        return f.read()


# In following extra handlers we use base64 encoding
# to store binary data. Even though, the nature
# of base64 is that it increases the total size,
# it doesn't really matter, because our images
# do not store big amounts of binary data. They
# are negligible comparing to pages size.
class pipes_data_extra_handler:
    def load(self, f, pload):
        size = pload.bytes
        data = f.read(size)
        return base64.encodebytes(data).decode('utf-8')

    def dump(self, extra, f, pload):
        data = decode_base64_data(extra)
        f.write(data)

    def skip(self, f, pload):
        f.seek(pload.bytes, os.SEEK_CUR)
        return pload.bytes


class sk_queues_extra_handler:
    def load(self, f, pload):
        size = pload.length
        data = f.read(size)
        return base64.encodebytes(data).decode('utf-8')

    def dump(self, extra, f, _unused):
        data = decode_base64_data(extra)
        f.write(data)

    def skip(self, f, pload):
        f.seek(pload.length, os.SEEK_CUR)
        return pload.length


class tcp_stream_extra_handler:
    def load(self, f, pbuff):
        d = {}

        inq = f.read(pbuff.inq_len)
        outq = f.read(pbuff.outq_len)

        d['inq'] = base64.encodebytes(inq).decode('utf-8')
        d['outq'] = base64.encodebytes(outq).decode('utf-8')

        return d

    def dump(self, extra, f, _unused):
        inq = decode_base64_data(extra['inq'])
        outq = decode_base64_data(extra['outq'])

        f.write(inq)
        f.write(outq)

    def skip(self, f, pbuff):
        f.seek(0, os.SEEK_END)
        return pbuff.inq_len + pbuff.outq_len


class bpfmap_data_extra_handler:
    def load(self, f, pload):
        size = pload.keys_bytes + pload.values_bytes
        data = f.read(size)
        return base64.encodebytes(data).decode('utf-8')

    def dump(self, extra, f, pload):
        data = base64.decodebytes(extra)
        f.write(data)

    def skip(self, f, pload):
        f.seek(pload.bytes, os.SEEK_CUR)
        return pload.bytes


class ipc_sem_set_handler:
    def load(self, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = sizeof_u16 * entry['nsems']
        rounded = round_up(size, sizeof_u64)
        s = self._get_sem_array()
        s.frombytes(f.read(size))
        f.seek(rounded - size, 1)
        return s.tolist()

    def dump(self, extra, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = sizeof_u16 * entry['nsems']
        rounded = round_up(size, sizeof_u64)
        s = self._get_sem_array()
        s.fromlist(extra)
        if len(s) != entry['nsems']:
            raise Exception("Number of semaphores mismatch")
        f.write(s.tobytes())
        f.write(b'\0' * (rounded - size))

    def skip(self, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = sizeof_u16 * entry['nsems']
        f.seek(round_up(size, sizeof_u64), os.SEEK_CUR)
        return size

    def _get_sem_array(self):
        s = array.array('H')
        if s.itemsize != sizeof_u16:
            raise Exception("Array size mismatch")
        return s


class ipc_msg_queue_handler:
    def load(self, f, pbuff):
        messages, _ = self._read_messages(f, pbuff)
        return messages

    def dump(self, extra, f, pbuff):
        for i in range(0, len(extra), 2):
            msg = pb.ipc_msg()
            pb2dict.dict2pb(extra[i], msg)
            msg_str = msg.SerializeToString()
            size = len(msg_str)
            f.write(struct.pack('i', size))
            f.write(msg_str)
            rounded = round_up(msg.msize, sizeof_u64)
            data = decode_base64_data(extra[i + 1])
            f.write(data[:msg.msize])
            f.write(b'\0' * (rounded - msg.msize))

    def skip(self, f, pbuff):
        _, pl_len = self._read_messages(f, pbuff, skip_data=True)
        return pl_len

    def _read_messages(self, f, pbuff, skip_data=False):
        entry = pb2dict.pb2dict(pbuff)
        messages = []
        pl_len = 0
        for x in range(0, entry['qnum']):
            buf = f.read(4)
            if len(buf) == 0:
                break
            size, = struct.unpack('i', buf)
            msg = pb.ipc_msg()
            msg.ParseFromString(f.read(size))
            rounded = round_up(msg.msize, sizeof_u64)
            pl_len += size + msg.msize

            if skip_data:
                f.seek(rounded, os.SEEK_CUR)
            else:
                data = f.read(msg.msize)
                f.seek(rounded - msg.msize, 1)
                messages.append(pb2dict.pb2dict(msg))
                messages.append(base64.encodebytes(data).decode('utf-8'))

        return messages, pl_len


class ipc_shm_handler:
    def load(self, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = entry['size']
        data = f.read(size)
        rounded = round_up(size, sizeof_u32)
        f.seek(rounded - size, 1)
        return base64.encodebytes(data).decode('utf-8')

    def dump(self, extra, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = entry['size']
        data = base64.decodebytes(extra)
        rounded = round_up(size, sizeof_u32)
        f.write(data[:size])
        f.write(b'\0' * (rounded - size))

    def skip(self, f, pbuff):
        entry = pb2dict.pb2dict(pbuff)
        size = entry['size']
        rounded = round_up(size, sizeof_u32)
        f.seek(rounded, os.SEEK_CUR)
        return size


handlers = {
    'INVENTORY': entry_handler(pb.inventory_entry),
    'CORE': entry_handler(pb.core_entry),
    'IDS': entry_handler(pb.task_kobj_ids_entry),
    'CREDS': entry_handler(pb.creds_entry),
    'UTSNS': entry_handler(pb.utsns_entry),
    'TIMENS': entry_handler(pb.timens_entry),
    'PIDNS': entry_handler(pb.pidns_entry),
    'IPC_VAR': entry_handler(pb.ipc_var_entry),
    'FS': entry_handler(pb.fs_entry),
    'GHOST_FILE': ghost_file_handler(),
    'MM': entry_handler(pb.mm_entry),
    'CGROUP': entry_handler(pb.cgroup_entry),
    'TCP_STREAM': entry_handler(pb.tcp_stream_entry,
                                tcp_stream_extra_handler()),
    'STATS': entry_handler(pb.stats_entry),
    'PAGEMAP': pagemap_handler(),  # Special one
    'PSTREE': entry_handler(pb.pstree_entry),
    'REG_FILES': entry_handler(pb.reg_file_entry),
    'NS_FILES': entry_handler(pb.ns_file_entry),
    'EVENTFD_FILE': entry_handler(pb.eventfd_file_entry),
    'EVENTPOLL_FILE': entry_handler(pb.eventpoll_file_entry),
    'EVENTPOLL_TFD': entry_handler(pb.eventpoll_tfd_entry),
    'SIGNALFD': entry_handler(pb.signalfd_entry),
    'TIMERFD': entry_handler(pb.timerfd_entry),
    'INOTIFY_FILE': entry_handler(pb.inotify_file_entry),
    'INOTIFY_WD': entry_handler(pb.inotify_wd_entry),
    'FANOTIFY_FILE': entry_handler(pb.fanotify_file_entry),
    'FANOTIFY_MARK': entry_handler(pb.fanotify_mark_entry),
    'VMAS': entry_handler(pb.vma_entry),
    'PIPES': entry_handler(pb.pipe_entry),
    'FIFO': entry_handler(pb.fifo_entry),
    'SIGACT': entry_handler(pb.sa_entry),
    'NETLINK_SK': entry_handler(pb.netlink_sk_entry),
    'REMAP_FPATH': entry_handler(pb.remap_file_path_entry),
    'MNTS': entry_handler(pb.mnt_entry),
    'TTY_FILES': entry_handler(pb.tty_file_entry),
    'TTY_INFO': entry_handler(pb.tty_info_entry),
    'TTY_DATA': entry_handler(pb.tty_data_entry),
    'RLIMIT': entry_handler(pb.rlimit_entry),
    'TUNFILE': entry_handler(pb.tunfile_entry),
    'EXT_FILES': entry_handler(pb.ext_file_entry),
    'IRMAP_CACHE': entry_handler(pb.irmap_cache_entry),
    'FILE_LOCKS': entry_handler(pb.file_lock_entry),
    'FDINFO': entry_handler(pb.fdinfo_entry),
    'UNIXSK': entry_handler(pb.unix_sk_entry),
    'INETSK': entry_handler(pb.inet_sk_entry),
    'PACKETSK': entry_handler(pb.packet_sock_entry),
    'ITIMERS': entry_handler(pb.itimer_entry),
    'POSIX_TIMERS': entry_handler(pb.posix_timer_entry),
    'NETDEV': entry_handler(pb.net_device_entry),
    'PIPES_DATA': entry_handler(pb.pipe_data_entry,
                                pipes_data_extra_handler()),
    'FIFO_DATA': entry_handler(pb.pipe_data_entry, pipes_data_extra_handler()),
    'SK_QUEUES': entry_handler(pb.sk_packet_entry, sk_queues_extra_handler()),
    'IPCNS_SHM': entry_handler(pb.ipc_shm_entry, ipc_shm_handler()),
    'IPCNS_SEM': entry_handler(pb.ipc_sem_entry, ipc_sem_set_handler()),
    'IPCNS_MSG': entry_handler(pb.ipc_msg_entry, ipc_msg_queue_handler()),
    'NETNS': entry_handler(pb.netns_entry),
    'USERNS': entry_handler(pb.userns_entry),
    'SECCOMP': entry_handler(pb.seccomp_entry),
    'AUTOFS': entry_handler(pb.autofs_entry),
    'FILES': entry_handler(pb.file_entry),
    'CPUINFO': entry_handler(pb.cpuinfo_entry),
    'MEMFD_FILE': entry_handler(pb.memfd_file_entry),
    'MEMFD_INODE': entry_handler(pb.memfd_inode_entry),
    'BPFMAP_FILE': entry_handler(pb.bpfmap_file_entry),
    'BPFMAP_DATA': entry_handler(pb.bpfmap_data_entry,
                                 bpfmap_data_extra_handler()),
    'APPARMOR': entry_handler(pb.apparmor_entry),
}


def __rhandler(f):
    # Images v1.1 NOTE: First read "first" magic.
    img_magic, = struct.unpack('i', f.read(4))
    if img_magic in (magic.by_name['IMG_COMMON'],
                     magic.by_name['IMG_SERVICE']):
        img_magic, = struct.unpack('i', f.read(4))

    try:
        m = magic.by_val[img_magic]
    except Exception:
        raise MagicException(img_magic)

    try:
        handler = handlers[m]
    except Exception:
        raise Exception("No handler found for image with magic " + m)

    return m, handler


def load(f, pretty=False, no_payload=False):
    """
    Convert criu image from binary format to dict(json).
    Takes a file-like object to read criu image from.
    Returns criu image in dict(json) format.
    """
    image = {}

    m, handler = __rhandler(f)

    image['magic'] = m
    image['entries'] = handler.load(f, pretty, no_payload)

    return image


def info(f):
    res = {}

    m, handler = __rhandler(f)

    res['magic'] = m
    res['count'] = handler.count(f)

    return res


def loads(s, pretty=False):
    """
    Same as load(), but takes a string.
    """
    f = io.BytesIO(s)
    return load(f, pretty)


def dump(img, f):
    """
    Convert criu image from dict(json) format to binary.
    Takes an image in dict(json) format and file-like
    object to write to.
    """
    m = img['magic']
    magic_val = magic.by_name[img['magic']]

    # Images v1.1 NOTE: use "second" magic to identify what "first"
    # should be written.
    if m != 'INVENTORY':
        if m in ('STATS', 'IRMAP_CACHE'):
            f.write(struct.pack('i', magic.by_name['IMG_SERVICE']))
        else:
            f.write(struct.pack('i', magic.by_name['IMG_COMMON']))

    f.write(struct.pack('i', magic_val))

    try:
        handler = handlers[m]
    except Exception:
        raise Exception("No handler found for image with such magic")

    handler.dump(img['entries'], f)


def dumps(img):
    """
    Same as dump(), but takes only an image and returns
    a string.
    """
    f = io.BytesIO(b'')
    dump(img, f)
    return f.getvalue()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: vma.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'vma.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tvma.proto\x1a\nopts.proto\"\xec\x01\n\tvma_entry\x12\x14\n\x05start\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\x03\x65nd\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\r\n\x05pgoff\x18\x03 \x02(\x04\x12\r\n\x05shmid\x18\x04 \x02(\x04\x12\x1c\n\x04prot\x18\x05 \x02(\rB\x0e\xd2?\x0b\x1a\tmmap.prot\x12\x1e\n\x05\x66lags\x18\x06 \x02(\rB\x0f\xd2?\x0c\x1a\nmmap.flags\x12 \n\x06status\x18\x07 \x02(\rB\x10\xd2?\r\x1a\x0bmmap.status\x12\n\n\x02\x66\x64\x18\x08 \x02(\x12\x12\x13\n\x04madv\x18\t \x01(\x04\x42\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x66\x64\x66lags\x18\n \x01(\rB\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vma_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['start']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['start']._serialized_options = b'\322?\002\010\001'
  _globals['_VMA_ENTRY'].fields_by_name['end']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['end']._serialized_options = b'\322?\002\010\001'
  _globals['_VMA_ENTRY'].fields_by_name['prot']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['prot']._serialized_options = b'\322?\013\032\tmmap.prot'
  _globals['_VMA_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\014\032\nmmap.flags'
  _globals['_VMA_ENTRY'].fields_by_name['status']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['status']._serialized_options = b'\322?\r\032\013mmap.status'
  _globals['_VMA_ENTRY'].fields_by_name['madv']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['madv']._serialized_options = b'\322?\002\010\001'
  _globals['_VMA_ENTRY'].fields_by_name['fdflags']._loaded_options = None
  _globals['_VMA_ENTRY'].fields_by_name['fdflags']._serialized_options = b'\322?\002\010\001'
  _globals['_VMA_ENTRY']._serialized_start=26
  _globals['_VMA_ENTRY']._serialized_end=262
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-s390.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-s390.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63ore-s390.proto\x1a\nopts.proto\"~\n\x14user_s390_regs_entry\x12\x10\n\x08psw_mask\x18\x01 \x02(\x04\x12\x10\n\x08psw_addr\x18\x02 \x02(\x04\x12\x0c\n\x04gprs\x18\x03 \x03(\x04\x12\x0c\n\x04\x61\x63rs\x18\x04 \x03(\r\x12\x11\n\torig_gpr2\x18\x05 \x02(\x04\x12\x13\n\x0bsystem_call\x18\x06 \x02(\r\"(\n\x18user_s390_vxrs_low_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\")\n\x19user_s390_vxrs_high_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"3\n\x16user_s390_fpregs_entry\x12\x0b\n\x03\x66pc\x18\x01 \x02(\r\x12\x0c\n\x04\x66prs\x18\x02 \x03(\x04\"%\n\x15user_s390_gs_cb_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\"1\n\x12user_s390_ri_entry\x12\r\n\x05ri_on\x18\x01 \x02(\r\x12\x0c\n\x04regs\x18\x02 \x03(\x04\"\x80\x03\n\x10thread_info_s390\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12,\n\x06gpregs\x18\x02 \x02(\x0b\x32\x15.user_s390_regs_entryB\x05\xd2?\x02\x08\x01\x12.\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x17.user_s390_fpregs_entryB\x05\xd2?\x02\x08\x01\x12\x32\n\x08vxrs_low\x18\x04 \x01(\x0b\x32\x19.user_s390_vxrs_low_entryB\x05\xd2?\x02\x08\x01\x12\x34\n\tvxrs_high\x18\x05 \x01(\x0b\x32\x1a.user_s390_vxrs_high_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_cb\x18\x06 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12,\n\x05gs_bc\x18\x07 \x01(\x0b\x32\x16.user_s390_gs_cb_entryB\x05\xd2?\x02\x08\x01\x12)\n\x05ri_cb\x18\x08 \x01(\x0b\x32\x13.user_s390_ri_entryB\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_s390_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['fpregs']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['fpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_low']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_low']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_high']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['vxrs_high']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_cb']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_cb']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_bc']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['gs_bc']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_S390'].fields_by_name['ri_cb']._loaded_options = None
  _globals['_THREAD_INFO_S390'].fields_by_name['ri_cb']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_S390_REGS_ENTRY']._serialized_start=31
  _globals['_USER_S390_REGS_ENTRY']._serialized_end=157
  _globals['_USER_S390_VXRS_LOW_ENTRY']._serialized_start=159
  _globals['_USER_S390_VXRS_LOW_ENTRY']._serialized_end=199
  _globals['_USER_S390_VXRS_HIGH_ENTRY']._serialized_start=201
  _globals['_USER_S390_VXRS_HIGH_ENTRY']._serialized_end=242
  _globals['_USER_S390_FPREGS_ENTRY']._serialized_start=244
  _globals['_USER_S390_FPREGS_ENTRY']._serialized_end=295
  _globals['_USER_S390_GS_CB_ENTRY']._serialized_start=297
  _globals['_USER_S390_GS_CB_ENTRY']._serialized_end=334
  _globals['_USER_S390_RI_ENTRY']._serialized_start=336
  _globals['_USER_S390_RI_ENTRY']._serialized_end=385
  _globals['_THREAD_INFO_S390']._serialized_start=388
  _globals['_THREAD_INFO_S390']._serialized_end=772
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tcp-stream.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'tcp-stream.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10tcp-stream.proto\x1a\nopts.proto\"e\n\x0etcp_opts_entry\x12\x0c\n\x04\x63ork\x18\x01 \x01(\x08\x12\x0f\n\x07nodelay\x18\x02 \x01(\x08\x12\x0f\n\x07keepcnt\x18\x03 \x01(\r\x12\x10\n\x08keepidle\x18\x04 \x01(\r\x12\x11\n\tkeepintvl\x18\x05 \x01(\r\"\xc8\x02\n\x10tcp_stream_entry\x12\x0f\n\x07inq_len\x18\x01 \x02(\r\x12\x0f\n\x07inq_seq\x18\x02 \x02(\r\x12\x10\n\x08outq_len\x18\x03 \x02(\r\x12\x10\n\x08outq_seq\x18\x04 \x02(\r\x12\x17\n\x08opt_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x12\n\nsnd_wscale\x18\x06 \x02(\r\x12\x11\n\tmss_clamp\x18\x07 \x02(\r\x12\x12\n\nrcv_wscale\x18\x08 \x01(\r\x12\x11\n\ttimestamp\x18\t \x01(\r\x12\x0c\n\x04\x63ork\x18\n \x01(\x08\x12\x0f\n\x07nodelay\x18\x0b \x01(\x08\x12\x10\n\x08unsq_len\x18\x0c \x01(\r\x12\x0f\n\x07snd_wl1\x18\r \x01(\r\x12\x0f\n\x07snd_wnd\x18\x0e \x01(\r\x12\x12\n\nmax_window\x18\x0f \x01(\r\x12\x0f\n\x07rcv_wnd\x18\x10 \x01(\r\x12\x0f\n\x07rcv_wup\x18\x11 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tcp_stream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TCP_STREAM_ENTRY'].fields_by_name['opt_mask']._loaded_options = None
  _globals['_TCP_STREAM_ENTRY'].fields_by_name['opt_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_TCP_OPTS_ENTRY']._serialized_start=32
  _globals['_TCP_OPTS_ENTRY']._serialized_end=133
  _globals['_TCP_STREAM_ENTRY']._serialized_start=136
  _globals['_TCP_STREAM_ENTRY']._serialized_end=464
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fsnotify.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'fsnotify.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fh_pb2 as fh__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66snotify.proto\x1a\nopts.proto\x1a\x08\x66h.proto\x1a\nfown.proto\"\x9e\x01\n\x10inotify_wd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05i_ino\x18\x02 \x02(\x04\x12\x13\n\x04mask\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x05 \x02(\rB\x05\xd2?\x02 \x01\x12\n\n\x02wd\x18\x06 \x02(\r\x12\x1b\n\x08\x66_handle\x18\x07 \x02(\x0b\x32\t.fh_entry\"p\n\x12inotify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x04 \x02(\x0b\x32\x0b.fown_entry\x12\x1d\n\x02wd\x18\x05 \x03(\x0b\x32\x11.inotify_wd_entry\"G\n\x19\x66\x61notify_inode_mark_entry\x12\r\n\x05i_ino\x18\x01 \x02(\x04\x12\x1b\n\x08\x66_handle\x18\x02 \x02(\x0b\x32\t.fh_entry\"9\n\x19\x66\x61notify_mount_mark_entry\x12\x0e\n\x06mnt_id\x18\x01 \x02(\r\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xea\x01\n\x13\x66\x61notify_mark_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x18\n\x04type\x18\x02 \x02(\x0e\x32\n.mark_type\x12\x15\n\x06mflags\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x1b\n\x0cignored_mask\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x14\n\x05s_dev\x18\x06 \x02(\rB\x05\xd2?\x02 \x01\x12&\n\x02ie\x18\x07 \x01(\x0b\x32\x1a.fanotify_inode_mark_entry\x12&\n\x02me\x18\x08 \x01(\x0b\x32\x1a.fanotify_mount_mark_entry\"\xa6\x01\n\x13\x66\x61notify_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12\x16\n\x07\x66\x61\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x16\n\x07\x65vflags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\"\n\x04mark\x18\x06 \x03(\x0b\x32\x14.fanotify_mark_entry*!\n\tmark_type\x12\t\n\x05INODE\x10\x01\x12\t\n\x05MOUNT\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsnotify_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['ignored_mask']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['ignored_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['s_dev']._loaded_options = None
  _globals['_INOTIFY_WD_ENTRY'].fields_by_name['s_dev']._serialized_options = b'\322?\002 \001'
  _globals['_INOTIFY_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_INOTIFY_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mflags']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mflags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mask']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['mask']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['ignored_mask']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['ignored_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['s_dev']._loaded_options = None
  _globals['_FANOTIFY_MARK_ENTRY'].fields_by_name['s_dev']._serialized_options = b'\322?\002 \001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['faflags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['faflags']._serialized_options = b'\322?\002\010\001'
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['evflags']._loaded_options = None
  _globals['_FANOTIFY_FILE_ENTRY'].fields_by_name['evflags']._serialized_options = b'\322?\002\010\001'
  _globals['_MARK_TYPE']._serialized_start=865
  _globals['_MARK_TYPE']._serialized_end=898
  _globals['_INOTIFY_WD_ENTRY']._serialized_start=53
  _globals['_INOTIFY_WD_ENTRY']._serialized_end=211
  _globals['_INOTIFY_FILE_ENTRY']._serialized_start=213
  _globals['_INOTIFY_FILE_ENTRY']._serialized_end=325
  _globals['_FANOTIFY_INODE_MARK_ENTRY']._serialized_start=327
  _globals['_FANOTIFY_INODE_MARK_ENTRY']._serialized_end=398
  _globals['_FANOTIFY_MOUNT_MARK_ENTRY']._serialized_start=400
  _globals['_FANOTIFY_MOUNT_MARK_ENTRY']._serialized_end=457
  _globals['_FANOTIFY_MARK_ENTRY']._serialized_start=460
  _globals['_FANOTIFY_MARK_ENTRY']._serialized_end=694
  _globals['_FANOTIFY_FILE_ENTRY']._serialized_start=697
  _globals['_FANOTIFY_FILE_ENTRY']._serialized_end=863
# @@protoc_insertion_point(module_scope)



import base64
import collections
import os
import quopri
import socket
from ipaddress import IPv4Address, IPv6Address, ip_address

from google.protobuf.descriptor import FieldDescriptor as FD

import opts_pb2


def _is_repeated(field):
    """Check if a field is repeated, compatible with protobuf 3.x and 7.x."""
    if hasattr(field, 'label'):
        return field.label == FD.LABEL_REPEATED
    return field.is_repeated

if "encodebytes" not in dir(base64):
    base64.encodebytes = base64.encodestring
    base64.decodebytes = base64.decodestring

# pb2dict and dict2pb are methods to convert pb to/from dict.
# Inspired by:
#   protobuf-to-dict - https://github.com/benhodgson/protobuf-to-dict
#   protobuf-json    - https://code.google.com/p/protobuf-json/
#   protobuf source  - https://code.google.com/p/protobuf/
# Both protobuf-to-dict/json do not fit here because of several reasons,
# here are some of them:
#   - both have a common bug in treating optional field with empty
#     repeated inside.
#   - protobuf-to-json is not available in pip or in any other python
#     repo, so it is hard to distribute and we can't rely on it.
#   - both do not treat enums in a way we would like to. They convert
#     protobuf enum to int, but we need a string here, because it is
#     much more informative. BTW, protobuf text_format converts pb
#     enums to string value too. (i.e. "march : x86_64" is better then
#     "march : 1").

_basic_cast = {
    FD.TYPE_FIXED64: int,
    FD.TYPE_FIXED32: int,
    FD.TYPE_SFIXED64: int,
    FD.TYPE_SFIXED32: int,
    FD.TYPE_INT64: int,
    FD.TYPE_UINT64: int,
    FD.TYPE_SINT64: int,
    FD.TYPE_INT32: int,
    FD.TYPE_UINT32: int,
    FD.TYPE_SINT32: int,
    FD.TYPE_BOOL: bool,
    FD.TYPE_STRING: str
}


def _marked_as_hex(field):
    return field.GetOptions().Extensions[opts_pb2.criu].hex


def _marked_as_ip(field):
    return field.GetOptions().Extensions[opts_pb2.criu].ipadd


def _marked_as_flags(field):
    return field.GetOptions().Extensions[opts_pb2.criu].flags


def _marked_as_dev(field):
    return field.GetOptions().Extensions[opts_pb2.criu].dev


def _marked_as_odev(field):
    return field.GetOptions().Extensions[opts_pb2.criu].odev


def _marked_as_dict(field):
    return field.GetOptions().Extensions[opts_pb2.criu].dict


def _custom_conv(field):
    return field.GetOptions().Extensions[opts_pb2.criu].conv


mmap_prot_map = [
    ('PROT_READ', 0x1),
    ('PROT_WRITE', 0x2),
    ('PROT_EXEC', 0x4),
]

mmap_flags_map = [
    ('MAP_SHARED', 0x1),
    ('MAP_PRIVATE', 0x2),
    ('MAP_DROPPABLE', 0x08),
    ('MAP_ANON', 0x20),
    ('MAP_GROWSDOWN', 0x0100),
]

mmap_status_map = [
    ('VMA_AREA_NONE', 0 << 0),
    ('VMA_AREA_REGULAR', 1 << 0),
    ('VMA_AREA_STACK', 1 << 1),
    ('VMA_AREA_VSYSCALL', 1 << 2),
    ('VMA_AREA_VDSO', 1 << 3),
    ('VMA_AREA_HEAP', 1 << 5),
    ('VMA_FILE_PRIVATE', 1 << 6),
    ('VMA_FILE_SHARED', 1 << 7),
    ('VMA_ANON_SHARED', 1 << 8),
    ('VMA_ANON_PRIVATE', 1 << 9),
    ('VMA_AREA_SYSVIPC', 1 << 10),
    ('VMA_AREA_SOCKET', 1 << 11),
    ('VMA_AREA_VVAR', 1 << 12),
    ('VMA_AREA_AIORING', 1 << 13),
    ('VMA_AREA_MEMFD', 1 << 14),
    ('VMA_AREA_SHSTK', 1 << 15),
    ('VMA_AREA_UPROBES', 1 << 17),
    ('VMA_UNSUPP', 1 << 31),
]

rfile_flags_map = [
    ('O_WRONLY', 0o00000001),
    ('O_RDWR', 0o00000002),
    ('O_CREAT', 0o00000100),
    ('O_EXCL', 0o00000200),
    ('O_NOCTTY', 0o00000400),
    ('O_TRUNC', 0o00001000),
    ('O_APPEND', 0o00002000),
    ('O_NONBLOCK', 0o00004000),
    ('O_DSYNC', 0o00010000),
    ('FASYNC', 0o00020000),
    ('O_DIRECT', 0o00040000),
    ('O_LARGEFILE', 0o00100000),
    ('O_DIRECTORY', 0o00200000),
    ('O_NOFOLLOW', 0o00400000),
    ('O_NOATIME', 0o01000000),
    ('O_CLOEXEC', 0o02000000),
]

seals_flags_map = [
    ('F_SEAL_SEAL', 0x0001),
    ('F_SEAL_SHRINK', 0x0002),
    ('F_SEAL_GROW', 0x0004),
    ('F_SEAL_WRITE', 0x0008),
    ('F_SEAL_FUTURE_WRITE', 0x0010),
]

pmap_flags_map = [
    ('PE_PARENT', 1 << 0),
    ('PE_LAZY', 1 << 1),
    ('PE_PRESENT', 1 << 2),
]

flags_maps = {
    'mmap.prot': mmap_prot_map,
    'mmap.flags': mmap_flags_map,
    'mmap.status': mmap_status_map,
    'rfile.flags': rfile_flags_map,
    'pmap.flags': pmap_flags_map,
    'seals.flags': seals_flags_map,
}

gen_maps = {
    'task_state': {
        1: 'Alive',
        3: 'Zombie',
        6: 'Stopped'
    },
}

sk_maps = {
    'family': {
        1: 'UNIX',
        2: 'INET',
        10: 'INET6',
        16: 'NETLINK',
        17: 'PACKET'
    },
    'type': {
        1: 'STREAM',
        2: 'DGRAM',
        3: 'RAW',
        5: 'SEQPACKET',
        10: 'PACKET'
    },
    'state': {
        1: 'ESTABLISHED',
        2: 'SYN_SENT',
        3: 'SYN_RECV',
        4: 'FIN_WAIT1',
        5: 'FIN_WAIT2',
        6: 'TIME_WAIT',
        7: 'CLOSE',
        8: 'CLOSE_WAIT',
        9: 'LAST_ACK',
        10: 'LISTEN'
    },
    'proto': {
        0: 'IP',
        6: 'TCP',
        17: 'UDP',
        136: 'UDPLITE'
    },
}

gen_rmaps = {
    k: {v2: k2
        for k2, v2 in list(v.items())}
    for k, v in list(gen_maps.items())
}
sk_rmaps = {
    k: {v2: k2
        for k2, v2 in list(v.items())}
    for k, v in list(sk_maps.items())
}

dict_maps = {
    'gen': (gen_maps, gen_rmaps),
    'sk': (sk_maps, sk_rmaps),
}


def map_flags(value, flags_map):
    bs = [x[0] for x in [x for x in flags_map if value & x[1]]]
    value &= ~sum([x[1] for x in flags_map])
    if value:
        bs.append("0x%x" % value)
    return " | ".join(bs)


def unmap_flags(value, flags_map):
    if value == '':
        return 0

    bd = dict(flags_map)
    return sum([
        int(str(bd.get(x, x)), 0)
        for x in [x.strip() for x in value.split('|')]
    ])


kern_minorbits = 20  # This is how kernel encodes dev_t in new format


def decode_dev(field, value):
    if _marked_as_odev(field):
        return "%d:%d" % (os.major(value), os.minor(value))
    else:
        return "%d:%d" % (value >> kern_minorbits,
                          value & ((1 << kern_minorbits) - 1))


def encode_dev(field, value):
    dev = [int(x) for x in value.split(':')]
    if _marked_as_odev(field):
        return os.makedev(dev[0], dev[1])
    else:
        return dev[0] << kern_minorbits | dev[1]


def encode_base64(value):
    return base64.encodebytes(value).decode()


def decode_base64(value):
    return base64.decodebytes(str.encode(value))


def encode_unix(value):
    return quopri.encodestring(value)


def decode_unix(value):
    return quopri.decodestring(value)


encode = {'unix_name': encode_unix}
decode = {'unix_name': decode_unix}


def get_bytes_enc(field):
    c = _custom_conv(field)
    if c:
        return encode[c]
    else:
        return encode_base64


def get_bytes_dec(field):
    c = _custom_conv(field)
    if c:
        return decode[c]
    else:
        return decode_base64


def is_string(value):
    # Python 3 compatibility
    if "basestring" in __builtins__:
        string_types = basestring  # noqa: F821
    else:
        string_types = (str, bytes)
    return isinstance(value, string_types)


def _pb2dict_cast(field, value, pretty=False, is_hex=False):
    if not is_hex:
        is_hex = _marked_as_hex(field)

    if field.type == FD.TYPE_MESSAGE:
        return pb2dict(value, pretty, is_hex)
    elif field.type == FD.TYPE_BYTES:
        return get_bytes_enc(field)(value)
    elif field.type == FD.TYPE_ENUM:
        return field.enum_type.values_by_number.get(value, None).name
    elif field.type in _basic_cast:
        cast = _basic_cast[field.type]
        if pretty and cast is int:
            if is_hex:
                # Fields that have (criu).hex = true option set
                # should be stored in hex string format.
                return "0x%x" % value

            if _marked_as_dev(field):
                return decode_dev(field, value)

            flags = _marked_as_flags(field)
            if flags:
                try:
                    flags_map = flags_maps[flags]
                except Exception:
                    return "0x%x" % value  # flags are better seen as hex anyway
                else:
                    return map_flags(value, flags_map)

            dct = _marked_as_dict(field)
            if dct:
                return dict_maps[dct][0][field.name].get(value, cast(value))

        return cast(value)
    else:
        raise Exception("Field(%s) has unsupported type %d" %
                        (field.name, field.type))


def pb2dict(pb, pretty=False, is_hex=False):
    """
    Convert protobuf msg to dictionary.
    Takes a protobuf message and returns a dict.
    """
    d = collections.OrderedDict() if pretty else {}
    for field, value in pb.ListFields():
        if _is_repeated(field):
            d_val = []
            if pretty and _marked_as_ip(field):
                if len(value) == 1:
                    v = socket.ntohl(value[0])
                    addr = IPv4Address(v)
                else:
                    v = 0 + (socket.ntohl(value[0]) << (32 * 3)) + \
                            (socket.ntohl(value[1]) << (32 * 2)) + \
                            (socket.ntohl(value[2]) << (32 * 1)) + \
                            (socket.ntohl(value[3]))
                    addr = IPv6Address(v)

                d_val.append(addr.compressed)
            else:
                for v in value:
                    d_val.append(_pb2dict_cast(field, v, pretty, is_hex))
        else:
            d_val = _pb2dict_cast(field, value, pretty, is_hex)

        try:
            d[field.name] = d_val.decode()
        except (UnicodeDecodeError, AttributeError):
            d[field.name] = d_val
    return d


def _dict2pb_cast(field, value):
    # Not considering TYPE_MESSAGE here, as repeated
    # and non-repeated messages need special treatment
    # in this case, and are handled separately.
    if field.type == FD.TYPE_BYTES:
        return get_bytes_dec(field)(value)
    elif field.type == FD.TYPE_ENUM:
        return field.enum_type.values_by_name.get(value, None).number
    elif field.type in _basic_cast:
        cast = _basic_cast[field.type]
        if cast is int and is_string(value):
            if _marked_as_dev(field):
                return encode_dev(field, value)

            flags = _marked_as_flags(field)
            if flags:
                try:
                    flags_map = flags_maps[flags]
                except Exception:
                    pass  # Try to use plain string cast
                else:
                    return unmap_flags(value, flags_map)

            dct = _marked_as_dict(field)
            if dct:
                ret = dict_maps[dct][1][field.name].get(value, None)
                if ret is None:
                    ret = cast(value, 0)
                return ret

            # Some int or long fields might be stored as hex
            # strings. See _pb2dict_cast.
            return cast(value, 0)
        else:
            return cast(value)
    else:
        raise Exception("Field(%s) has unsupported type %d" %
                        (field.name, field.type))


def dict2pb(d, pb):
    """
    Convert dictionary to protobuf msg.
    Takes dict and protobuf message to be merged into.
    """
    for field in pb.DESCRIPTOR.fields:
        if field.name not in d:
            continue
        value = d[field.name]
        if _is_repeated(field):
            pb_val = getattr(pb, field.name, None)
            if is_string(value[0]) and _marked_as_ip(field):
                val = ip_address(value[0])
                if val.version == 4:
                    pb_val.append(socket.htonl(int(val)))
                elif val.version == 6:
                    ival = int(val)
                    pb_val.append(socket.htonl((ival >> (32 * 3)) & 0xFFFFFFFF))
                    pb_val.append(socket.htonl((ival >> (32 * 2)) & 0xFFFFFFFF))
                    pb_val.append(socket.htonl((ival >> (32 * 1)) & 0xFFFFFFFF))
                    pb_val.append(socket.htonl((ival >> (32 * 0)) & 0xFFFFFFFF))
                else:
                    raise Exception("Unknown IP address version %d" %
                                    val.version)
                continue

            for v in value:
                if field.type == FD.TYPE_MESSAGE:
                    dict2pb(v, pb_val.add())
                else:
                    pb_val.append(_dict2pb_cast(field, v))
        else:
            if field.type == FD.TYPE_MESSAGE:
                # SetInParent method acts just like has_* = true in C,
                # and helps to properly treat cases when we have optional
                # field with empty repeated inside.
                getattr(pb, field.name).SetInParent()

                dict2pb(value, getattr(pb, field.name, None))
            else:
                setattr(pb, field.name, _dict2pb_cast(field, value))
    return pb



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-inet.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sk-inet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2
import tcp_stream_pb2 as tcp__stream__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsk-inet.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\x1a\x10tcp-stream.proto\"^\n\x11ip_opts_raw_entry\x12\x0f\n\x07hdrincl\x18\x01 \x01(\x08\x12\x10\n\x08nodefrag\x18\x02 \x01(\x08\x12\x10\n\x08\x63hecksum\x18\x03 \x01(\x08\x12\x14\n\x0cicmpv_filter\x18\x04 \x03(\r\"m\n\rip_opts_entry\x12\x10\n\x08\x66reebind\x18\x01 \x01(\x08\x12\x1f\n\x03raw\x18\x04 \x01(\x0b\x32\x12.ip_opts_raw_entry\x12\x0f\n\x07pktinfo\x18\x05 \x01(\x08\x12\x0b\n\x03tos\x18\x06 \x01(\r\x12\x0b\n\x03ttl\x18\x07 \x01(\r\"\xd1\x03\n\rinet_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x17\n\x06\x66\x61mily\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x15\n\x04type\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05proto\x18\x05 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x06 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x10\n\x08src_port\x18\x07 \x02(\r\x12\x10\n\x08\x64st_port\x18\x08 \x02(\r\x12\x14\n\x05\x66lags\x18\t \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\n \x02(\r\x12\x17\n\x08src_addr\x18\x0b \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x08\x64st_addr\x18\x0c \x03(\rB\x05\xd2?\x02\x10\x01\x12\x19\n\x04\x66own\x18\r \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x0e \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0e\n\x06v6only\x18\x0f \x01(\x08\x12\x1f\n\x07ip_opts\x18\x10 \x01(\x0b\x32\x0e.ip_opts_entry\x12\x0e\n\x06ifname\x18\x11 \x01(\t\x12\r\n\x05ns_id\x18\x12 \x01(\r\x12\x1e\n\x08shutdown\x18\x13 \x01(\x0e\x32\x0c.sk_shutdown\x12!\n\x08tcp_opts\x18\x14 \x01(\x0b\x32\x0f.tcp_opts_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_inet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['family']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['family']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['type']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['proto']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['proto']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['state']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['state']._serialized_options = b'\322?\0042\002sk'
  _globals['_INET_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_INET_SK_ENTRY'].fields_by_name['src_addr']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['src_addr']._serialized_options = b'\322?\002\020\001'
  _globals['_INET_SK_ENTRY'].fields_by_name['dst_addr']._loaded_options = None
  _globals['_INET_SK_ENTRY'].fields_by_name['dst_addr']._serialized_options = b'\322?\002\020\001'
  _globals['_IP_OPTS_RAW_ENTRY']._serialized_start=74
  _globals['_IP_OPTS_RAW_ENTRY']._serialized_end=168
  _globals['_IP_OPTS_ENTRY']._serialized_start=170
  _globals['_IP_OPTS_ENTRY']._serialized_end=279
  _globals['_INET_SK_ENTRY']._serialized_start=282
  _globals['_INET_SK_ENTRY']._serialized_end=747
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sysctl.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sysctl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csysctl.proto\"E\n\x0csysctl_entry\x12\x19\n\x04type\x18\x01 \x02(\x0e\x32\x0b.SysctlType\x12\x0c\n\x04iarg\x18\x02 \x01(\x05\x12\x0c\n\x04sarg\x18\x03 \x01(\t*%\n\nSysctlType\x12\x0b\n\x07\x43TL_STR\x10\x05\x12\n\n\x06\x43TL_32\x10\x06')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sysctl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSCTLTYPE']._serialized_start=87
  _globals['_SYSCTLTYPE']._serialized_end=124
  _globals['_SYSCTL_ENTRY']._serialized_start=16
  _globals['_SYSCTL_ENTRY']._serialized_end=85
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sk-unix.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sk-unix.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rsk-unix.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\x10\x66ile_perms_entry\x12\x0c\n\x04mode\x18\x01 \x02(\r\x12\x0b\n\x03uid\x18\x02 \x02(\r\x12\x0b\n\x03gid\x18\x03 \x02(\r\"\x87\x03\n\runix_sk_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03ino\x18\x02 \x02(\r\x12\x15\n\x04type\x18\x03 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x16\n\x05state\x18\x04 \x02(\rB\x07\xd2?\x04\x32\x02sk\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x15\n\x06uflags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x62\x61\x63klog\x18\x07 \x02(\r\x12\x0c\n\x04peer\x18\x08 \x02(\r\x12\x19\n\x04\x66own\x18\t \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\n \x02(\x0b\x32\x0e.sk_opts_entry\x12\x1c\n\x04name\x18\x0b \x02(\x0c\x42\x0e\xd2?\x0b:\tunix_name\x12\x1e\n\x08shutdown\x18\x0c \x01(\x0e\x32\x0c.sk_shutdown\x12%\n\nfile_perms\x18\r \x01(\x0b\x32\x11.file_perms_entry\x12\x10\n\x08name_dir\x18\x0e \x01(\t\x12\x0f\n\x07\x64\x65leted\x18\x0f \x01(\x08\x12\r\n\x05ns_id\x18\x10 \x01(\r\x12\x12\n\x06mnt_id\x18\x11 \x01(\x11:\x02-1')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sk_unix_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['type']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['type']._serialized_options = b'\322?\0042\002sk'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['state']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['state']._serialized_options = b'\322?\0042\002sk'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['uflags']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['uflags']._serialized_options = b'\322?\002\010\001'
  _globals['_UNIX_SK_ENTRY'].fields_by_name['name']._loaded_options = None
  _globals['_UNIX_SK_ENTRY'].fields_by_name['name']._serialized_options = b'\322?\013:\tunix_name'
  _globals['_FILE_PERMS_ENTRY']._serialized_start=56
  _globals['_FILE_PERMS_ENTRY']._serialized_end=114
  _globals['_UNIX_SK_ENTRY']._serialized_start=117
  _globals['_UNIX_SK_ENTRY']._serialized_end=508
# @@protoc_insertion_point(module_scope)



import os
import sys

# Python 3.14 introduced changes that break some older protobuf C-extension
# builds shipped by certain distributions. If the user has not explicitly
# selected an implementation, default to the pure-Python backend to avoid
# import failures (e.g. "Metaclasses with custom tp_new are not supported").
#
# This is a temporary compatibility workaround and should be removed once
# protobuf packages fully support Python 3.14+.
if sys.version_info >= (3, 14):
    os.environ.setdefault("PROTOCOL_BUFFERS_PYTHON_IMPLEMENTATION", "python")

from . import rpc_pb2 as rpc
from . import images
from .criu import criu, CRIUExceptionExternal, CRIUException
from .criu import CR_DEFAULT_SERVICE_ADDRESS
from .version import __version__

__all__ = (
    "rpc",
    "images",
    "criu",
    "CRIUExceptionExternal",
    "CRIUException",
    "CR_DEFAULT_SERVICE_ADDRESS",
    "__version__",
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: stats.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bstats.proto\"\xe0\x02\n\x10\x64ump_stats_entry\x12\x15\n\rfreezing_time\x18\x01 \x02(\r\x12\x13\n\x0b\x66rozen_time\x18\x02 \x02(\r\x12\x14\n\x0cmemdump_time\x18\x03 \x02(\r\x12\x15\n\rmemwrite_time\x18\x04 \x02(\r\x12\x15\n\rpages_scanned\x18\x05 \x02(\x04\x12\x1c\n\x14pages_skipped_parent\x18\x06 \x02(\x04\x12\x15\n\rpages_written\x18\x07 \x02(\x04\x12\x15\n\rirmap_resolve\x18\x08 \x01(\r\x12\x12\n\npages_lazy\x18\t \x02(\x04\x12\x12\n\npage_pipes\x18\n \x01(\x04\x12\x16\n\x0epage_pipe_bufs\x18\x0b \x01(\x04\x12\x17\n\x0fshpages_scanned\x18\x0c \x01(\x04\x12\x1e\n\x16shpages_skipped_parent\x18\r \x01(\x04\x12\x17\n\x0fshpages_written\x18\x0e \x01(\x04\"\x8c\x01\n\x13restore_stats_entry\x12\x16\n\x0epages_compared\x18\x01 \x02(\x04\x12\x19\n\x11pages_skipped_cow\x18\x02 \x02(\x04\x12\x14\n\x0c\x66orking_time\x18\x03 \x02(\r\x12\x14\n\x0crestore_time\x18\x04 \x02(\r\x12\x16\n\x0epages_restored\x18\x05 \x01(\x04\"U\n\x0bstats_entry\x12\x1f\n\x04\x64ump\x18\x01 \x01(\x0b\x32\x11.dump_stats_entry\x12%\n\x07restore\x18\x02 \x01(\x0b\x32\x14.restore_stats_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DUMP_STATS_ENTRY']._serialized_start=16
  _globals['_DUMP_STATS_ENTRY']._serialized_end=368
  _globals['_RESTORE_STATS_ENTRY']._serialized_start=371
  _globals['_RESTORE_STATS_ENTRY']._serialized_end=511
  _globals['_STATS_ENTRY']._serialized_start=513
  _globals['_STATS_ENTRY']._serialized_end=598
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ipc-sem.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'ipc-sem.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ipc_desc_pb2 as ipc__desc__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ripc-sem.proto\x1a\x0eipc-desc.proto\"=\n\ripc_sem_entry\x12\x1d\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x0f.ipc_desc_entry\x12\r\n\x05nsems\x18\x02 \x02(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ipc_sem_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IPC_SEM_ENTRY']._serialized_start=33
  _globals['_IPC_SEM_ENTRY']._serialized_end=94
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cpuinfo.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'cpuinfo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcpuinfo.proto\"\xa3\x02\n\x11\x63puinfo_x86_entry\x12,\n\tvendor_id\x18\x01 \x02(\x0e\x32\x19.cpuinfo_x86_entry.vendor\x12\x12\n\ncpu_family\x18\x02 \x02(\r\x12\r\n\x05model\x18\x03 \x02(\r\x12\x10\n\x08stepping\x18\x04 \x02(\r\x12\x16\n\x0e\x63\x61pability_ver\x18\x05 \x02(\r\x12\x12\n\ncapability\x18\x06 \x03(\r\x12\x10\n\x08model_id\x18\x07 \x01(\t\x12\x16\n\x0exfeatures_mask\x18\x08 \x01(\x04\x12\x12\n\nxsave_size\x18\t \x01(\r\x12\x16\n\x0exsave_size_max\x18\n \x01(\r\")\n\x06vendor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05INTEL\x10\x01\x12\x07\n\x03\x41MD\x10\x02\"\x84\x01\n\x13\x63puinfo_ppc64_entry\x12/\n\x06\x65ndian\x18\x01 \x02(\x0e\x32\x1f.cpuinfo_ppc64_entry.endianness\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"-\n\nendianness\x12\r\n\tBIGENDIAN\x10\x00\x12\x10\n\x0cLITTLEENDIAN\x10\x01\"#\n\x12\x63puinfo_s390_entry\x12\r\n\x05hwcap\x18\x02 \x03(\x04\"\x8a\x01\n\rcpuinfo_entry\x12%\n\tx86_entry\x18\x01 \x03(\x0b\x32\x12.cpuinfo_x86_entry\x12)\n\x0bppc64_entry\x18\x02 \x03(\x0b\x32\x14.cpuinfo_ppc64_entry\x12\'\n\ns390_entry\x18\x03 \x03(\x0b\x32\x13.cpuinfo_s390_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cpuinfo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CPUINFO_X86_ENTRY']._serialized_start=18
  _globals['_CPUINFO_X86_ENTRY']._serialized_end=309
  _globals['_CPUINFO_X86_ENTRY_VENDOR']._serialized_start=268
  _globals['_CPUINFO_X86_ENTRY_VENDOR']._serialized_end=309
  _globals['_CPUINFO_PPC64_ENTRY']._serialized_start=312
  _globals['_CPUINFO_PPC64_ENTRY']._serialized_end=444
  _globals['_CPUINFO_PPC64_ENTRY_ENDIANNESS']._serialized_start=399
  _globals['_CPUINFO_PPC64_ENTRY_ENDIANNESS']._serialized_end=444
  _globals['_CPUINFO_S390_ENTRY']._serialized_start=446
  _globals['_CPUINFO_S390_ENTRY']._serialized_end=481
  _globals['_CPUINFO_ENTRY']._serialized_start=484
  _globals['_CPUINFO_ENTRY']._serialized_end=622
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eventpoll.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'eventpoll.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x65ventpoll.proto\x1a\nfown.proto\"u\n\x13\x65ventpoll_tfd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0b\n\x03tfd\x18\x02 \x02(\r\x12\x0e\n\x06\x65vents\x18\x03 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x04\x12\x0b\n\x03\x64\x65v\x18\x05 \x01(\r\x12\r\n\x05inode\x18\x06 \x01(\x04\x12\x0b\n\x03pos\x18\x07 \x01(\x04\"o\n\x14\x65ventpoll_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\r\n\x05\x66lags\x18\x02 \x02(\r\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12!\n\x03tfd\x18\x04 \x03(\x0b\x32\x14.eventpoll_tfd_entry')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eventpoll_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVENTPOLL_TFD_ENTRY']._serialized_start=31
  _globals['_EVENTPOLL_TFD_ENTRY']._serialized_end=148
  _globals['_EVENTPOLL_FILE_ENTRY']._serialized_start=150
  _globals['_EVENTPOLL_FILE_ENTRY']._serialized_end=261
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: apparmor.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'apparmor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61pparmor.proto\"\'\n\taa_policy\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x62lob\x18\x02 \x02(\x0c\"]\n\x0c\x61\x61_namespace\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x1c\n\x08policies\x18\x02 \x03(\x0b\x32\n.aa_policy\x12!\n\nnamespaces\x18\x03 \x03(\x0b\x32\r.aa_namespace\"3\n\x0e\x61pparmor_entry\x12!\n\nnamespaces\x18\x01 \x03(\x0b\x32\r.aa_namespace')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'apparmor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AA_POLICY']._serialized_start=18
  _globals['_AA_POLICY']._serialized_end=57
  _globals['_AA_NAMESPACE']._serialized_start=59
  _globals['_AA_NAMESPACE']._serialized_end=152
  _globals['_APPARMOR_ENTRY']._serialized_start=154
  _globals['_APPARMOR_ENTRY']._serialized_end=205
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-loongarch64.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-loongarch64.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x63ore-loongarch64.proto\x1a\nopts.proto\"9\n\x1duser_loongarch64_gpregs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\n\n\x02pc\x18\x02 \x02(\x04\"H\n\x1duser_loongarch64_fpregs_entry\x12\x0c\n\x04regs\x18\x01 \x03(\x04\x12\x0b\n\x03\x66\x63\x63\x18\x02 \x02(\x04\x12\x0c\n\x04\x66\x63sr\x18\x03 \x02(\r\"\xb3\x01\n\x17thread_info_loongarch64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\x04\x12\x35\n\x06gpregs\x18\x03 \x02(\x0b\x32\x1e.user_loongarch64_gpregs_entryB\x05\xd2?\x02\x08\x01\x12\x35\n\x06\x66pregs\x18\x04 \x02(\x0b\x32\x1e.user_loongarch64_fpregs_entryB\x05\xd2?\x02\x08\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_loongarch64_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['fpregs']._loaded_options = None
  _globals['_THREAD_INFO_LOONGARCH64'].fields_by_name['fpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_LOONGARCH64_GPREGS_ENTRY']._serialized_start=38
  _globals['_USER_LOONGARCH64_GPREGS_ENTRY']._serialized_end=95
  _globals['_USER_LOONGARCH64_FPREGS_ENTRY']._serialized_start=97
  _globals['_USER_LOONGARCH64_FPREGS_ENTRY']._serialized_end=169
  _globals['_THREAD_INFO_LOONGARCH64']._serialized_start=172
  _globals['_THREAD_INFO_LOONGARCH64']._serialized_end=351
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core-x86.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core-x86.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ore-x86.proto\x1a\nopts.proto\"\x9c\x03\n\x13user_x86_regs_entry\x12\x0b\n\x03r15\x18\x01 \x02(\x04\x12\x0b\n\x03r14\x18\x02 \x02(\x04\x12\x0b\n\x03r13\x18\x03 \x02(\x04\x12\x0b\n\x03r12\x18\x04 \x02(\x04\x12\n\n\x02\x62p\x18\x05 \x02(\x04\x12\n\n\x02\x62x\x18\x06 \x02(\x04\x12\x0b\n\x03r11\x18\x07 \x02(\x04\x12\x0b\n\x03r10\x18\x08 \x02(\x04\x12\n\n\x02r9\x18\t \x02(\x04\x12\n\n\x02r8\x18\n \x02(\x04\x12\n\n\x02\x61x\x18\x0b \x02(\x04\x12\n\n\x02\x63x\x18\x0c \x02(\x04\x12\n\n\x02\x64x\x18\r \x02(\x04\x12\n\n\x02si\x18\x0e \x02(\x04\x12\n\n\x02\x64i\x18\x0f \x02(\x04\x12\x0f\n\x07orig_ax\x18\x10 \x02(\x04\x12\n\n\x02ip\x18\x11 \x02(\x04\x12\n\n\x02\x63s\x18\x12 \x02(\x04\x12\r\n\x05\x66lags\x18\x13 \x02(\x04\x12\n\n\x02sp\x18\x14 \x02(\x04\x12\n\n\x02ss\x18\x15 \x02(\x04\x12\x0f\n\x07\x66s_base\x18\x16 \x02(\x04\x12\x0f\n\x07gs_base\x18\x17 \x02(\x04\x12\n\n\x02\x64s\x18\x18 \x02(\x04\x12\n\n\x02\x65s\x18\x19 \x02(\x04\x12\n\n\x02\x66s\x18\x1a \x02(\x04\x12\n\n\x02gs\x18\x1b \x02(\x04\x12)\n\x04mode\x18\x1c \x01(\x0e\x32\x13.user_x86_regs_mode:\x06NATIVE\"<\n\x12user_x86_cet_entry\x12\x12\n\x03\x63\x65t\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\x03ssp\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\"\xd2\x01\n\x14user_x86_xsave_entry\x12\x11\n\txstate_bv\x18\x01 \x02(\x04\x12\x12\n\nymmh_space\x18\x02 \x03(\r\x12\x14\n\x0c\x62ndreg_state\x18\x03 \x03(\x04\x12\x14\n\x0c\x62ndcsr_state\x18\x04 \x03(\x04\x12\x12\n\nopmask_reg\x18\x05 \x03(\x04\x12\x11\n\tzmm_upper\x18\x06 \x03(\x04\x12\x10\n\x08hi16_zmm\x18\x07 \x03(\x04\x12\x0c\n\x04pkru\x18\x08 \x03(\r\x12 \n\x03\x63\x65t\x18\t \x01(\x0b\x32\x13.user_x86_cet_entry\"\xe4\x01\n\x15user_x86_fpregs_entry\x12\x0b\n\x03\x63wd\x18\x01 \x02(\r\x12\x0b\n\x03swd\x18\x02 \x02(\r\x12\x0b\n\x03twd\x18\x03 \x02(\r\x12\x0b\n\x03\x66op\x18\x04 \x02(\r\x12\x0b\n\x03rip\x18\x05 \x02(\x04\x12\x0b\n\x03rdp\x18\x06 \x02(\x04\x12\r\n\x05mxcsr\x18\x07 \x02(\r\x12\x12\n\nmxcsr_mask\x18\x08 \x02(\r\x12\x10\n\x08st_space\x18\t \x03(\r\x12\x11\n\txmm_space\x18\n \x03(\r\x12\x0f\n\x07padding\x18\x0b \x03(\r\x12$\n\x05xsave\x18\r \x01(\x0b\x32\x15.user_x86_xsave_entry\"\xe5\x01\n\x0buser_desc_t\x12\x14\n\x0c\x65ntry_number\x18\x01 \x02(\r\x12\x11\n\tbase_addr\x18\x02 \x02(\r\x12\r\n\x05limit\x18\x03 \x02(\r\x12\x11\n\tseg_32bit\x18\x04 \x02(\x08\x12\x12\n\ncontents_h\x18\x05 \x02(\x08\x12\x12\n\ncontents_l\x18\x06 \x02(\x08\x12\x1c\n\x0eread_exec_only\x18\x07 \x02(\x08:\x04true\x12\x16\n\x0elimit_in_pages\x18\x08 \x02(\x08\x12\x1d\n\x0fseg_not_present\x18\t \x02(\x08:\x04true\x12\x0e\n\x06usable\x18\n \x02(\x08\"\xa0\x01\n\x0fthread_info_x86\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12+\n\x06gpregs\x18\x02 \x02(\x0b\x32\x14.user_x86_regs_entryB\x05\xd2?\x02\x08\x01\x12&\n\x06\x66pregs\x18\x03 \x02(\x0b\x32\x16.user_x86_fpregs_entry\x12\x19\n\x03tls\x18\x04 \x03(\x0b\x32\x0c.user_desc_t*,\n\x12user_x86_regs_mode\x12\n\n\x06NATIVE\x10\x01\x12\n\n\x06\x43OMPAT\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_x86_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['cet']._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['cet']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['ssp']._loaded_options = None
  _globals['_USER_X86_CET_ENTRY'].fields_by_name['ssp']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_X86'].fields_by_name['clear_tid_addr']._loaded_options = None
  _globals['_THREAD_INFO_X86'].fields_by_name['clear_tid_addr']._serialized_options = b'\322?\002\010\001'
  _globals['_THREAD_INFO_X86'].fields_by_name['gpregs']._loaded_options = None
  _globals['_THREAD_INFO_X86'].fields_by_name['gpregs']._serialized_options = b'\322?\002\010\001'
  _globals['_USER_X86_REGS_MODE']._serialized_start=1346
  _globals['_USER_X86_REGS_MODE']._serialized_end=1390
  _globals['_USER_X86_REGS_ENTRY']._serialized_start=31
  _globals['_USER_X86_REGS_ENTRY']._serialized_end=443
  _globals['_USER_X86_CET_ENTRY']._serialized_start=445
  _globals['_USER_X86_CET_ENTRY']._serialized_end=505
  _globals['_USER_X86_XSAVE_ENTRY']._serialized_start=508
  _globals['_USER_X86_XSAVE_ENTRY']._serialized_end=718
  _globals['_USER_X86_FPREGS_ENTRY']._serialized_start=721
  _globals['_USER_X86_FPREGS_ENTRY']._serialized_end=949
  _globals['_USER_DESC_T']._serialized_start=952
  _globals['_USER_DESC_T']._serialized_end=1181
  _globals['_THREAD_INFO_X86']._serialized_start=1184
  _globals['_THREAD_INFO_X86']._serialized_end=1344
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: remap-file-path.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'remap-file-path.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15remap-file-path.proto\"[\n\x15remap_file_path_entry\x12\x0f\n\x07orig_id\x18\x01 \x02(\r\x12\x10\n\x08remap_id\x18\x02 \x02(\r\x12\x1f\n\nremap_type\x18\x03 \x01(\x0e\x32\x0b.remap_type*/\n\nremap_type\x12\n\n\x06LINKED\x10\x00\x12\t\n\x05GHOST\x10\x01\x12\n\n\x06PROCFS\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'remap_file_path_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REMAP_TYPE']._serialized_start=118
  _globals['_REMAP_TYPE']._serialized_end=165
  _globals['_REMAP_FILE_PATH_ENTRY']._serialized_start=25
  _globals['_REMAP_FILE_PATH_ENTRY']._serialized_end=116
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: rseq.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'rseq.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nrseq.proto\"i\n\nrseq_entry\x12\x18\n\x10rseq_abi_pointer\x18\x01 \x02(\x04\x12\x15\n\rrseq_abi_size\x18\x02 \x02(\r\x12\x11\n\tsignature\x18\x03 \x02(\r\x12\x17\n\x0frseq_cs_pointer\x18\x04 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'rseq_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RSEQ_ENTRY']._serialized_start=14
  _globals['_RSEQ_ENTRY']._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: file-lock.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'file-lock.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x66ile-lock.proto\"b\n\x0f\x66ile_lock_entry\x12\x0c\n\x04\x66lag\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0b\n\x03pid\x18\x03 \x02(\x05\x12\n\n\x02\x66\x64\x18\x04 \x02(\x05\x12\r\n\x05start\x18\x05 \x02(\x03\x12\x0b\n\x03len\x18\x06 \x02(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'file_lock_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FILE_LOCK_ENTRY']._serialized_start=19
  _globals['_FILE_LOCK_ENTRY']._serialized_end=117
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ipc-var.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'ipc-var.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ripc-var.proto\"\xfd\x02\n\ripc_var_entry\x12\x10\n\x08sem_ctls\x18\x01 \x03(\r\x12\x12\n\nmsg_ctlmax\x18\x02 \x02(\r\x12\x12\n\nmsg_ctlmnb\x18\x03 \x02(\r\x12\x12\n\nmsg_ctlmni\x18\x04 \x02(\r\x12\x13\n\x0b\x61uto_msgmni\x18\x05 \x02(\r\x12\x12\n\nshm_ctlmax\x18\x06 \x02(\x04\x12\x12\n\nshm_ctlall\x18\x07 \x02(\x04\x12\x12\n\nshm_ctlmni\x18\x08 \x02(\r\x12\x17\n\x0fshm_rmid_forced\x18\t \x02(\r\x12\x15\n\rmq_queues_max\x18\n \x02(\r\x12\x12\n\nmq_msg_max\x18\x0b \x02(\r\x12\x16\n\x0emq_msgsize_max\x18\x0c \x02(\r\x12\x16\n\x0emq_msg_default\x18\r \x01(\r\x12\x1a\n\x12mq_msgsize_default\x18\x0e \x01(\r\x12\x13\n\x0bmsg_next_id\x18\x0f \x01(\r\x12\x13\n\x0bsem_next_id\x18\x10 \x01(\r\x12\x13\n\x0bshm_next_id\x18\x11 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ipc_var_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IPC_VAR_ENTRY']._serialized_start=18
  _globals['_IPC_VAR_ENTRY']._serialized_end=399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: core.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'core.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import core_x86_pb2 as core__x86__pb2
import core_arm_pb2 as core__arm__pb2
import core_aarch64_pb2 as core__aarch64__pb2
import core_ppc64_pb2 as core__ppc64__pb2
import core_s390_pb2 as core__s390__pb2
import core_mips_pb2 as core__mips__pb2
import core_loongarch64_pb2 as core__loongarch64__pb2
import core_riscv64_pb2 as core__riscv64__pb2
import rlimit_pb2 as rlimit__pb2
import timer_pb2 as timer__pb2
import creds_pb2 as creds__pb2
import sa_pb2 as sa__pb2
import siginfo_pb2 as siginfo__pb2
import rseq_pb2 as rseq__pb2
import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncore.proto\x1a\x0e\x63ore-x86.proto\x1a\x0e\x63ore-arm.proto\x1a\x12\x63ore-aarch64.proto\x1a\x10\x63ore-ppc64.proto\x1a\x0f\x63ore-s390.proto\x1a\x0f\x63ore-mips.proto\x1a\x16\x63ore-loongarch64.proto\x1a\x12\x63ore-riscv64.proto\x1a\x0crlimit.proto\x1a\x0btimer.proto\x1a\x0b\x63reds.proto\x1a\x08sa.proto\x1a\rsiginfo.proto\x1a\nrseq.proto\x1a\nopts.proto\"\x9c\x04\n\x0ftask_core_entry\x12\x1c\n\ntask_state\x18\x01 \x02(\rB\x08\xd2?\x05\x32\x03gen\x12\x11\n\texit_code\x18\x02 \x02(\r\x12\x13\n\x0bpersonality\x18\x03 \x02(\r\x12\r\n\x05\x66lags\x18\x04 \x02(\r\x12\x19\n\nblk_sigset\x18\x05 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0c\n\x04\x63omm\x18\x06 \x02(\t\x12\"\n\x06timers\x18\x07 \x01(\x0b\x32\x12.task_timers_entry\x12$\n\x07rlimits\x18\x08 \x01(\x0b\x32\x13.task_rlimits_entry\x12\x0e\n\x06\x63g_set\x18\t \x01(\r\x12&\n\tsignals_s\x18\n \x01(\x0b\x32\x13.signal_queue_entry\x12\'\n\x10old_seccomp_mode\x18\x0b \x01(\x0e\x32\r.seccomp_mode\x12\x1a\n\x12old_seccomp_filter\x18\x0c \x01(\r\x12\x10\n\x08loginuid\x18\r \x01(\r\x12\x15\n\room_score_adj\x18\x0e \x01(\x05\x12\x1d\n\nsigactions\x18\x0f \x03(\x0b\x32\t.sa_entry\x12\x17\n\x0f\x63hild_subreaper\x18\x12 \x01(\x08\x12\"\n\x13\x62lk_sigset_extended\x18\x14 \x01(\x04\x42\x05\xd2?\x02\x08\x01\x12\x12\n\nstop_signo\x18\x15 \x01(\r\x12+\n\x1cmembarrier_registration_mask\x18\x16 \x01(\rB\x05\xd2?\x02\x08\x01\"\xf6\x01\n\x13task_kobj_ids_entry\x12\r\n\x05vm_id\x18\x01 \x02(\r\x12\x10\n\x08\x66iles_id\x18\x02 \x02(\r\x12\r\n\x05\x66s_id\x18\x03 \x02(\r\x12\x12\n\nsighand_id\x18\x04 \x02(\r\x12\x11\n\tpid_ns_id\x18\x05 \x01(\r\x12\x11\n\tnet_ns_id\x18\x06 \x01(\r\x12\x11\n\tipc_ns_id\x18\x07 \x01(\r\x12\x11\n\tuts_ns_id\x18\x08 \x01(\r\x12\x11\n\tmnt_ns_id\x18\t \x01(\r\x12\x12\n\nuser_ns_id\x18\n \x01(\r\x12\x14\n\x0c\x63group_ns_id\x18\x0b \x01(\r\x12\x12\n\ntime_ns_id\x18\x0c \x01(\r\"D\n\x10thread_sas_entry\x12\r\n\x05ss_sp\x18\x01 \x02(\x04\x12\x0f\n\x07ss_size\x18\x02 \x02(\x04\x12\x10\n\x08ss_flags\x18\x03 \x02(\r\"\xa1\x03\n\x11thread_core_entry\x12\x11\n\tfutex_rla\x18\x01 \x02(\x04\x12\x15\n\rfutex_rla_len\x18\x02 \x02(\r\x12\x12\n\nsched_nice\x18\x03 \x01(\x11\x12\x14\n\x0csched_policy\x18\x04 \x01(\r\x12\x12\n\nsched_prio\x18\x05 \x01(\r\x12\x12\n\nblk_sigset\x18\x06 \x01(\x04\x12\x1e\n\x03sas\x18\x07 \x01(\x0b\x32\x11.thread_sas_entry\x12\x12\n\npdeath_sig\x18\x08 \x01(\r\x12&\n\tsignals_p\x18\t \x01(\x0b\x32\x13.signal_queue_entry\x12\x1b\n\x05\x63reds\x18\n \x01(\x0b\x32\x0c.creds_entry\x12#\n\x0cseccomp_mode\x18\x0b \x01(\x0e\x32\r.seccomp_mode\x12\x16\n\x0eseccomp_filter\x18\x0c \x01(\r\x12\x0c\n\x04\x63omm\x18\r \x01(\t\x12\x1b\n\x13\x62lk_sigset_extended\x18\x0e \x01(\x04\x12\x1f\n\nrseq_entry\x18\x0f \x01(\x0b\x32\x0b.rseq_entry\x12\x0e\n\x06\x63g_set\x18\x10 \x01(\r\"4\n\x12task_rlimits_entry\x12\x1e\n\x07rlimits\x18\x01 \x03(\x0b\x32\r.rlimit_entry\"\xca\x04\n\ncore_entry\x12 \n\x05mtype\x18\x01 \x02(\x0e\x32\x11.core_entry.march\x12%\n\x0bthread_info\x18\x02 \x01(\x0b\x32\x10.thread_info_x86\x12 \n\x06ti_arm\x18\x06 \x01(\x0b\x32\x10.thread_info_arm\x12(\n\nti_aarch64\x18\x08 \x01(\x0b\x32\x14.thread_info_aarch64\x12$\n\x08ti_ppc64\x18\t \x01(\x0b\x32\x12.thread_info_ppc64\x12\"\n\x07ti_s390\x18\n \x01(\x0b\x32\x11.thread_info_s390\x12\"\n\x07ti_mips\x18\x0b \x01(\x0b\x32\x11.thread_info_mips\x12\x30\n\x0eti_loongarch64\x18\x0c \x01(\x0b\x32\x18.thread_info_loongarch64\x12(\n\nti_riscv64\x18\r \x01(\x0b\x32\x14.thread_info_riscv64\x12\x1c\n\x02tc\x18\x03 \x01(\x0b\x32\x10.task_core_entry\x12!\n\x03ids\x18\x04 \x01(\x0b\x32\x14.task_kobj_ids_entry\x12\'\n\x0bthread_core\x18\x05 \x01(\x0b\x32\x12.thread_core_entry\"s\n\x05march\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06X86_64\x10\x01\x12\x07\n\x03\x41RM\x10\x02\x12\x0b\n\x07\x41\x41RCH64\x10\x03\x12\t\n\x05PPC64\x10\x04\x12\x08\n\x04S390\x10\x05\x12\x08\n\x04MIPS\x10\x06\x12\x0f\n\x0bLOONGARCH64\x10\x07\x12\x0b\n\x07RISCV64\x10\x08*4\n\x0cseccomp_mode\x12\x0c\n\x08\x64isabled\x10\x00\x12\n\n\x06strict\x10\x01\x12\n\n\x06\x66ilter\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'core_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TASK_CORE_ENTRY'].fields_by_name['task_state']._loaded_options = None
  _globals['_TASK_CORE_ENTRY'].fields_by_name['task_state']._serialized_options = b'\322?\0052\003gen'
  _globals['_TASK_CORE_ENTRY'].fields_by_name['blk_sigset']._loaded_options = None
  _globals['_TASK_CORE_ENTRY'].fields_by_name['blk_sigset']._serialized_options = b'\322?\002\010\001'
  _globals['_TASK_CORE_ENTRY'].fields_by_name['blk_sigset_extended']._loaded_options = None
  _globals['_TASK_CORE_ENTRY'].fields_by_name['blk_sigset_extended']._serialized_options = b'\322?\002\010\001'
  _globals['_TASK_CORE_ENTRY'].fields_by_name['membarrier_registration_mask']._loaded_options = None
  _globals['_TASK_CORE_ENTRY'].fields_by_name['membarrier_registration_mask']._serialized_options = b'\322?\002\010\001'
  _globals['_SECCOMP_MODE']._serialized_start=2176
  _globals['_SECCOMP_MODE']._serialized_end=2228
  _globals['_TASK_CORE_ENTRY']._serialized_start=252
  _globals['_TASK_CORE_ENTRY']._serialized_end=792
  _globals['_TASK_KOBJ_IDS_ENTRY']._serialized_start=795
  _globals['_TASK_KOBJ_IDS_ENTRY']._serialized_end=1041
  _globals['_THREAD_SAS_ENTRY']._serialized_start=1043
  _globals['_THREAD_SAS_ENTRY']._serialized_end=1111
  _globals['_THREAD_CORE_ENTRY']._serialized_start=1114
  _globals['_THREAD_CORE_ENTRY']._serialized_end=1531
  _globals['_TASK_RLIMITS_ENTRY']._serialized_start=1533
  _globals['_TASK_RLIMITS_ENTRY']._serialized_end=1585
  _globals['_CORE_ENTRY']._serialized_start=1588
  _globals['_CORE_ENTRY']._serialized_end=2174
  _globals['_CORE_ENTRY_MARCH']._serialized_start=2059
  _globals['_CORE_ENTRY_MARCH']._serialized_end=2174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pagemap.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'pagemap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpagemap.proto\x1a\nopts.proto\" \n\x0cpagemap_head\x12\x10\n\x08pages_id\x18\x01 \x02(\r\"\x83\x01\n\rpagemap_entry\x12\x14\n\x05vaddr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x0f\x63ompat_nr_pages\x18\x02 \x02(\r\x12\x11\n\tin_parent\x18\x03 \x01(\x08\x12\x1e\n\x05\x66lags\x18\x04 \x01(\rB\x0f\xd2?\x0c\x1a\npmap.flags\x12\x10\n\x08nr_pages\x18\x05 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pagemap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['vaddr']._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['vaddr']._serialized_options = b'\322?\002\010\001'
  _globals['_PAGEMAP_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_PAGEMAP_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\014\032\npmap.flags'
  _globals['_PAGEMAP_HEAD']._serialized_start=29
  _globals['_PAGEMAP_HEAD']._serialized_end=61
  _globals['_PAGEMAP_ENTRY']._serialized_start=64
  _globals['_PAGEMAP_ENTRY']._serialized_end=195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: netdev.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'netdev.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import macvlan_pb2 as macvlan__pb2
import opts_pb2 as opts__pb2
import tun_pb2 as tun__pb2
import sysctl_pb2 as sysctl__pb2
import sit_pb2 as sit__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cnetdev.proto\x1a\rmacvlan.proto\x1a\nopts.proto\x1a\ttun.proto\x1a\x0csysctl.proto\x1a\tsit.proto\"\xdd\x02\n\x10net_device_entry\x12\x16\n\x04type\x18\x01 \x02(\x0e\x32\x08.nd_type\x12\x0f\n\x07ifindex\x18\x02 \x02(\r\x12\x0b\n\x03mtu\x18\x03 \x02(\r\x12\x14\n\x05\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04name\x18\x05 \x02(\t\x12\x1c\n\x03tun\x18\x06 \x01(\x0b\x32\x0f.tun_link_entry\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\x0c\x12\x0c\n\x04\x63onf\x18\x08 \x03(\x05\x12\x1c\n\x05\x63onf4\x18\t \x03(\x0b\x32\r.sysctl_entry\x12\x1c\n\x05\x63onf6\x18\n \x03(\x0b\x32\r.sysctl_entry\x12$\n\x07macvlan\x18\x0b \x01(\x0b\x32\x13.macvlan_link_entry\x12\x14\n\x0cpeer_ifindex\x18\x0c \x01(\r\x12\x11\n\tpeer_nsid\x18\r \x01(\r\x12\x0e\n\x06master\x18\x0e \x01(\r\x12\x17\n\x03sit\x18\x0f \x01(\x0b\x32\n.sit_entry\"7\n\x08netns_id\x12\x14\n\x0ctarget_ns_id\x18\x01 \x02(\r\x12\x15\n\rnetnsid_value\x18\x02 \x02(\x05\"\xaa\x02\n\x0bnetns_entry\x12\x10\n\x08\x64\x65\x66_conf\x18\x01 \x03(\x05\x12\x10\n\x08\x61ll_conf\x18\x02 \x03(\x05\x12 \n\tdef_conf4\x18\x03 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tall_conf4\x18\x04 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tdef_conf6\x18\x05 \x03(\x0b\x32\r.sysctl_entry\x12 \n\tall_conf6\x18\x06 \x03(\x0b\x32\r.sysctl_entry\x12\x18\n\x05nsids\x18\x07 \x03(\x0b\x32\t.netns_id\x12\x0f\n\x07\x65xt_key\x18\x08 \x01(\t\x12 \n\tunix_conf\x18\t \x03(\x0b\x32\r.sysctl_entry\x12\"\n\x0bipv4_sysctl\x18\n \x03(\x0b\x32\r.sysctl_entry*d\n\x07nd_type\x12\x0c\n\x08LOOPBACK\x10\x01\x12\x08\n\x04VETH\x10\x02\x12\x07\n\x03TUN\x10\x03\x12\x0b\n\x07\x45XTLINK\x10\x04\x12\t\n\x05VENET\x10\x05\x12\n\n\x06\x42RIDGE\x10\x06\x12\x0b\n\x07MACVLAN\x10\x07\x12\x07\n\x03SIT\x10\x08')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'netdev_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NET_DEVICE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_NET_DEVICE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_ND_TYPE']._serialized_start=789
  _globals['_ND_TYPE']._serialized_end=889
  _globals['_NET_DEVICE_ENTRY']._serialized_start=80
  _globals['_NET_DEVICE_ENTRY']._serialized_end=429
  _globals['_NETNS_ID']._serialized_start=431
  _globals['_NETNS_ID']._serialized_end=486
  _globals['_NETNS_ENTRY']._serialized_start=489
  _globals['_NETNS_ENTRY']._serialized_end=787
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: binfmt-misc.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'binfmt-misc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x62infmt-misc.proto\"\x96\x01\n\x11\x62infmt_misc_entry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0f\n\x07\x65nabled\x18\x02 \x02(\x08\x12\x13\n\x0binterpreter\x18\x03 \x02(\t\x12\r\n\x05\x66lags\x18\x04 \x01(\t\x12\x11\n\textension\x18\x05 \x01(\t\x12\r\n\x05magic\x18\x06 \x01(\t\x12\x0c\n\x04mask\x18\x07 \x01(\t\x12\x0e\n\x06offset\x18\x08 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'binfmt_misc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BINFMT_MISC_ENTRY']._serialized_start=22
  _globals['_BINFMT_MISC_ENTRY']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: timerfd.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'timerfd.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rtimerfd.proto\x1a\nopts.proto\x1a\nfown.proto\"\xc4\x01\n\rtimerfd_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x14\n\x05\x66lags\x18\x02 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x03 \x02(\x0b\x32\x0b.fown_entry\x12\x0f\n\x07\x63lockid\x18\x04 \x02(\r\x12\r\n\x05ticks\x18\x05 \x02(\x04\x12\x1c\n\rsettime_flags\x18\x06 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04vsec\x18\x07 \x02(\x04\x12\r\n\x05vnsec\x18\x08 \x02(\x04\x12\x0c\n\x04isec\x18\t \x02(\x04\x12\r\n\x05insec\x18\n \x02(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'timerfd_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TIMERFD_ENTRY'].fields_by_name['settime_flags']._loaded_options = None
  _globals['_TIMERFD_ENTRY'].fields_by_name['settime_flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TIMERFD_ENTRY']._serialized_start=42
  _globals['_TIMERFD_ENTRY']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tty.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'tty.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ttty.proto\x1a\nopts.proto\x1a\nfown.proto\"U\n\rwinsize_entry\x12\x0e\n\x06ws_row\x18\x01 \x02(\r\x12\x0e\n\x06ws_col\x18\x02 \x02(\r\x12\x11\n\tws_xpixel\x18\x03 \x02(\r\x12\x11\n\tws_ypixel\x18\x04 \x02(\r\"\x95\x01\n\rtermios_entry\x12\x0f\n\x07\x63_iflag\x18\x01 \x02(\r\x12\x0f\n\x07\x63_oflag\x18\x02 \x02(\r\x12\x0f\n\x07\x63_cflag\x18\x03 \x02(\r\x12\x0f\n\x07\x63_lflag\x18\x04 \x02(\r\x12\x0e\n\x06\x63_line\x18\x05 \x02(\r\x12\x10\n\x08\x63_ispeed\x18\x06 \x02(\r\x12\x10\n\x08\x63_ospeed\x18\x07 \x02(\r\x12\x0c\n\x04\x63_cc\x18\x08 \x03(\r\"\x1e\n\rtty_pty_entry\x12\r\n\x05index\x18\x01 \x02(\r\".\n\x0etty_data_entry\x12\x0e\n\x06tty_id\x18\x01 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x02(\x0c\"\xc3\x02\n\x0etty_info_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x16\n\x04type\x18\x02 \x02(\x0e\x32\x08.TtyType\x12\x0e\n\x06locked\x18\x03 \x02(\x08\x12\x11\n\texclusive\x18\x04 \x02(\x08\x12\x13\n\x0bpacket_mode\x18\x05 \x02(\x08\x12\x0b\n\x03sid\x18\x06 \x02(\r\x12\x0c\n\x04pgrp\x18\x07 \x02(\r\x12\x0c\n\x04rdev\x18\x08 \x02(\r\x12\x1f\n\x07termios\x18\t \x01(\x0b\x32\x0e.termios_entry\x12&\n\x0etermios_locked\x18\n \x01(\x0b\x32\x0e.termios_entry\x12\x1f\n\x07winsize\x18\x0b \x01(\x0b\x32\x0e.winsize_entry\x12\x1b\n\x03pty\x18\x0c \x01(\x0b\x32\x0e.tty_pty_entry\x12\x0b\n\x03\x64\x65v\x18\r \x01(\r\x12\x0b\n\x03uid\x18\x0e \x01(\r\x12\x0b\n\x03gid\x18\x0f \x01(\r\"s\n\x0etty_file_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x13\n\x0btty_info_id\x18\x02 \x02(\r\x12\x14\n\x05\x66lags\x18\x03 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x19\n\x04\x66own\x18\x04 \x02(\x0b\x32\x0b.fown_entry\x12\x0f\n\x07regf_id\x18\x06 \x01(\r*W\n\x07TtyType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03PTY\x10\x01\x12\x0b\n\x07\x43ONSOLE\x10\x02\x12\x06\n\x02VT\x10\x03\x12\x08\n\x04\x43TTY\x10\x04\x12\x0b\n\x07\x45XT_TTY\x10\x05\x12\n\n\x06SERIAL\x10\x06')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tty_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TTY_FILE_ENTRY'].fields_by_name['flags']._loaded_options = None
  _globals['_TTY_FILE_ENTRY'].fields_by_name['flags']._serialized_options = b'\322?\002\010\001'
  _globals['_TTYTYPE']._serialized_start=799
  _globals['_TTYTYPE']._serialized_end=886
  _globals['_WINSIZE_ENTRY']._serialized_start=37
  _globals['_WINSIZE_ENTRY']._serialized_end=122
  _globals['_TERMIOS_ENTRY']._serialized_start=125
  _globals['_TERMIOS_ENTRY']._serialized_end=274
  _globals['_TTY_PTY_ENTRY']._serialized_start=276
  _globals['_TTY_PTY_ENTRY']._serialized_end=306
  _globals['_TTY_DATA_ENTRY']._serialized_start=308
  _globals['_TTY_DATA_ENTRY']._serialized_end=354
  _globals['_TTY_INFO_ENTRY']._serialized_start=357
  _globals['_TTY_INFO_ENTRY']._serialized_end=680
  _globals['_TTY_FILE_ENTRY']._serialized_start=682
  _globals['_TTY_FILE_ENTRY']._serialized_end=797
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sit.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'sit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsit.proto\x1a\nopts.proto\"\xc9\x02\n\tsit_entry\x12\x0c\n\x04link\x18\x01 \x01(\r\x12\x14\n\x05local\x18\x02 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x15\n\x06remote\x18\x03 \x03(\rB\x05\xd2?\x02\x10\x01\x12\x0b\n\x03ttl\x18\x04 \x01(\r\x12\x0b\n\x03tos\x18\x05 \x01(\r\x12\x10\n\x08pmtudisc\x18\x06 \x01(\x08\x12\r\n\x05proto\x18\x07 \x01(\r\x12\r\n\x05\x66lags\x18\x08 \x01(\r\x12\x12\n\nencap_type\x18\t \x01(\r\x12\x13\n\x0b\x65ncap_flags\x18\n \x01(\r\x12\x13\n\x0b\x65ncap_sport\x18\x0b \x01(\r\x12\x13\n\x0b\x65ncap_dport\x18\x0c \x01(\r\x12\x14\n\x0crd_prefixlen\x18\r \x01(\r\x12\x18\n\trd_prefix\x18\x0e \x03(\rB\x05\xd2?\x02\x10\x01\x12\x17\n\x0frelay_prefixlen\x18\x0f \x01(\r\x12\x1b\n\x0crelay_prefix\x18\x10 \x03(\rB\x05\xd2?\x02\x10\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['local']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['local']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['remote']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['remote']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['rd_prefix']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['rd_prefix']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY'].fields_by_name['relay_prefix']._loaded_options = None
  _globals['_SIT_ENTRY'].fields_by_name['relay_prefix']._serialized_options = b'\322?\002\020\001'
  _globals['_SIT_ENTRY']._serialized_start=26
  _globals['_SIT_ENTRY']._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: opts.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'opts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nopts.proto\x1a google/protobuf/descriptor.proto\"m\n\tCRIU_Opts\x12\x0b\n\x03hex\x18\x01 \x01(\x08\x12\r\n\x05ipadd\x18\x02 \x01(\x08\x12\r\n\x05\x66lags\x18\x03 \x01(\t\x12\x0b\n\x03\x64\x65v\x18\x04 \x01(\x08\x12\x0c\n\x04odev\x18\x05 \x01(\x08\x12\x0c\n\x04\x64ict\x18\x06 \x01(\t\x12\x0c\n\x04\x63onv\x18\x07 \x01(\t:8\n\x04\x63riu\x12\x1d.google.protobuf.FieldOptions\x18\xfa\x07 \x01(\x0b\x32\n.CRIU_Opts')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CRIU_OPTS']._serialized_start=48
  _globals['_CRIU_OPTS']._serialized_end=157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: userns.proto
# Protobuf Python Version: 7.35.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    7,
    35,
    1,
    '',
    'userns.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cuserns.proto\"C\n\x0euid_gid_extent\x12\r\n\x05\x66irst\x18\x01 \x02(\r\x12\x13\n\x0blower_first\x18\x02 \x02(\r\x12\r\n\x05\x63ount\x18\x03 \x02(\r\"R\n\x0cuserns_entry\x12 \n\x07uid_map\x18\x01 \x03(\x0b\x32\x0f.uid_gid_extent\x12 \n\x07gid_map\x18\x02 \x03(\x0b\x32\x0f.uid_gid_extent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'userns_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UID_GID_EXTENT']._serialized_start=16
  _globals['_UID_GID_EXTENT']._serialized_end=83
  _globals['_USERNS_ENTRY']._serialized_start=85
  _globals['_USERNS_ENTRY']._serialized_end=167
# @@protoc_insertion_point(module_scope)
